# -*- coding: utf-8 -*-

# Copyright (C) 2012-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
#
# X2Go Session Broker is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# X2Go Session Broker is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

import unittest
import tempfile

# Python X2GoBroker modules
import x2gobroker.utils

class TestX2GoBrokerUtils(unittest.TestCase):

    ### TEST FUNCTION: normalize_hostnames() with server lists (ListType)

    def test_normalize_hostnames_listtype(self):

        server_list = ['ts01', 'ts02', 'ts03',]
        expected_server_list = ['ts01', 'ts02', 'ts03',]
        server_list_n, subdomains = x2gobroker.utils.normalize_hostnames(server_list)
        server_list_n.sort()
        self.assertEqual(expected_server_list, server_list_n)
        self.assertEqual([], subdomains)

        server_list = ['ts01.intern', 'ts02.intern', 'ts03.intern',]
        expected_server_list = ['ts01', 'ts02', 'ts03',]
        server_list_n, subdomains = x2gobroker.utils.normalize_hostnames(server_list)
        server_list_n.sort()
        self.assertEqual(expected_server_list, server_list_n)
        self.assertEqual(['intern'], subdomains)

        server_list = ['ts01.intern', 'ts02.intern', 'ts03.extern',]
        expected_server_list = ['ts01.intern', 'ts02.intern', 'ts03.extern',]
        server_list_n, subdomains = x2gobroker.utils.normalize_hostnames(server_list)
        server_list_n.sort()
        subdomains.sort()
        self.assertEqual(expected_server_list, server_list_n)
        self.assertEqual(['extern', 'intern'], subdomains)

        server_tuple = ('ts01.intern', 'ts02.intern', 'ts03.extern',)
        expected_server_list = ['ts01.intern', 'ts02.intern', 'ts03.extern',]
        server_list_n, subdomains = x2gobroker.utils.normalize_hostnames(server_tuple)
        server_list_n.sort()
        subdomains.sort()
        self.assertEqual(expected_server_list, server_list_n)
        self.assertEqual(['extern', 'intern'], subdomains)

    ### TEST FUNCTION: normalize_hostnames() with server load (DictType)

    def test_normalize_hostnames_dicttype(self):

        server_load = {'ts01': 10, 'ts02': 20, 'ts03': 30,}
        expected_server_load = {'ts01': 10, 'ts02': 20, 'ts03': 30,}
        server_load_n, subdomains = x2gobroker.utils.normalize_hostnames(server_load)
        sln_keys = server_load_n.keys()
        esl_keys = expected_server_load.keys()
        sln_keys.sort()
        esl_keys.sort()
        self.assertEqual(esl_keys, sln_keys)
        self.assertEqual([], subdomains)

        server_load = {'ts01.intern': 10, 'ts02.intern': 20, 'ts03.intern': 30,}
        expected_server_load = {'ts01': 10, 'ts02': 20, 'ts03': 30,}
        server_load_n, subdomains = x2gobroker.utils.normalize_hostnames(server_load)
        sln_keys = server_load_n.keys()
        esl_keys = expected_server_load.keys()
        sln_keys.sort()
        esl_keys.sort()
        self.assertEqual(esl_keys, sln_keys)
        self.assertEqual(['intern'], subdomains)

        server_load = {'ts01.intern': 10, 'ts02.intern': 20, 'ts03.extern': 30,}
        expected_server_load = {'ts01.intern': 10, 'ts02.intern': 20, 'ts03.extern': 30,}
        server_load_n, subdomains = x2gobroker.utils.normalize_hostnames(server_load)
        sln_keys = server_load_n.keys()
        esl_keys = expected_server_load.keys()
        sln_keys.sort()
        esl_keys.sort()
        subdomains.sort()
        self.assertEqual(esl_keys, sln_keys)
        self.assertEqual(['extern', 'intern'], subdomains)


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestX2GoBrokerUtils))
    return suite
